.. _help:

Get help
========

Mailing lists
-------------

Mailing list to ping all admins at once: `scikit-hep-admins`_.

Forum for general matters, announcements and discussions concerning the Scikit-HEP project : `scikit-hep-forum`_.

.. _scikit-hep-admins: scikit-hep-admins@googlegroups.com
.. _scikit-hep-forum: scikit-hep-forum@googlegroups.com

On GitHub
----------

You can also get help via the
`GitHub pages <https://github.com/scikit-hep/scikit-hep/>`_, e.g. filing `an issue <https://github.com/scikit-hep/scikit-hep/issues>`_.
